@@ -5,6 +5,7 @@ import (
 	"net/http"
 	"net/url"
 	"path"
+	"strings"
 
 	"github.com/go-chi/chi/middleware"
 	"github.com/go-kit/kit/log"
@@ -30,6 +31,18 @@ func MiddlewareSetUpstream(upstream *url.URL) Middleware {
 	}
 }
 
+func MiddlewareSetUpMetricsWritestream(upstream *url.URL) Middleware {
+	return func(r *http.Request) {
+		r.URL.Scheme = upstream.Scheme
+		r.URL.Host = upstream.Host
+		if strings.Contains(upstream.Host, "thanos-receive") || strings.HasPrefix(upstream.Host, "127.0.0.1") {
+			r.URL.Path = path.Join(upstream.Path, r.URL.Path)
+		} else {
+			r.URL.Path = "/"
+		}
+	}
+}
+
 func MiddlewareLogger(logger log.Logger) Middleware {
 	return func(r *http.Request) {
 		rlogger := log.With(logger, "request", middleware.GetReqID(r.Context()))
